@@ -2,8 +2,8 @@
 #
 # This file is part of the tangoctl project
 #
-# Copyright (c) 2018 Tiago Coutinho
-# Distributed under the MIT license. See LICENSE for more info.
+# Copyright (c) 2018-2020 Tiago Coutinho
+# Distributed under the GPLv3 license. See LICENSE for more info.
 
 from __future__ import absolute_import
 
@@ -44,10 +44,10 @@ import click
 
 import gevent
 
-from . import tangoctl
+from . import core
 
 
-class error(tangoctl.ErrorHandler):
+class error(core.ErrorHandler):
     def __init__(self, verbose=False):
         echo = functools.partial(click.echo, err=True)
         super(error, self).__init__(echo=echo, verbose=verbose)
@@ -281,39 +281,36 @@ def _table(*args, **kwargs):
     return tabulate.tabulate(*args, **kwargs)
 
 
-def _server_str(server, color=False):
+def _server_str(server):
     server = server if isinstance(server, str) else server.name
-    return click.style(server, fg="cyan" if color else None)
+    return click.style(server, fg="cyan")
 
 
-def _server_host_str(server, color=False):
+def _server_host_str(server):
     host = server if isinstance(server, str) else server.host
     host = "---" if host == "nada" else host
-    return click.style(host, fg="white" if color else None, dim=True if color else None)
+    return click.style(host, fg="white", dim=True)
 
 
-def _device_class_str(dev, color=False):
+def _device_class_str(dev):
     klass = dev if isinstance(dev, str) else dev.klass
-    return click.style(klass, fg="magenta" if color else None)
+    return click.style(klass, fg="magenta")
 
 
-def _device_str(dev, color=False):
+def _device_str(dev):
     dev = dev if isinstance(dev, str) else dev.name
-    return click.style(dev, fg="white" if color else None)
+    return click.style(dev, fg="white")
 
 
-def _alias_str(dev, color=False):
+def _alias_str(dev):
     dev = dev if isinstance(dev, str) else dev.alias
     dev = "---" if dev is None else dev
-    return click.style(dev, fg="blue" if color else None)
+    return click.style(dev, fg="blue")
 
 
-def _device_exported_str(dev, color=False):
+def _device_exported_str(dev):
     text = "Exported" if dev.exported else "Not. Exp."
-    if color:
-        fg = "green" if dev.exported else "red"
-    else:
-        fg = None
+    fg = "green" if dev.exported else "red"
     return click.style(text, fg=fg)
 
 
@@ -328,60 +325,61 @@ def _time_color(us):
 
 
 def _attribute_info_table(device, attribute):
-    info = tangoctl.device_attribute_info(device, attribute)
+    info = core.device_attribute_info(device, attribute)
     return [
         ["Name", info.name],
-        ["Type", tangoctl.type_str(info.data_type, info.data_format)],
-        ["Access", tangoctl.access_str(info.writable)],
-        ["Display level", tangoctl.value_str(info.disp_level)],
+        ["Type", core.type_str(info.data_type, info.data_format)],
+        ["Access", core.access_str(info.writable)],
+        ["Display level", core.value_str(info.disp_level)],
         ["Label", info.label],
-        ["Memorized", tangoctl.value_str(info.memorized)],
+        ["Memorized", core.value_str(info.memorized)],
         ["Max. dim", (info.max_dim_x, info.max_dim_y)],
         [
             "Range",
             "({}, {})".format(
-                tangoctl.value_str(info.min_value), tangoctl.value_str(info.max_value)
+                core.value_str(info.min_value), core.value_str(info.max_value)
             ),
         ],
         [
             "Alarms",
             "({}, {})".format(
-                tangoctl.value_str(info.alarms.min_alarm),
-                tangoctl.value_str(info.alarms.max_alarm),
+                core.value_str(info.alarms.min_alarm),
+                core.value_str(info.alarms.max_alarm),
             ),
         ],
         [
             "Warnings",
             "({}, {})".format(
-                tangoctl.value_str(info.alarms.min_warning),
-                tangoctl.value_str(info.alarms.max_warning),
+                core.value_str(info.alarms.min_warning),
+                core.value_str(info.alarms.max_warning),
             ),
         ],
         ["Label", info.label],
-        ["Description", tangoctl.value_str(info.description)],
+        ["Description", core.value_str(info.description)],
         ["Format", info.format],
-        ["Unit", tangoctl.value_str(info.unit)],
-        ["Display unit", tangoctl.value_str(info.display_unit)],
-        ["Std. unit", tangoctl.value_str(info.standard_unit)],
+        ["Unit", core.value_str(info.unit)],
+        ["Display unit", core.value_str(info.display_unit)],
+        ["Std. unit", core.value_str(info.standard_unit)],
         [
             "Arch. abs. change",
-            tangoctl.value_str(info.events.arch_event.archive_abs_change),
+            core.value_str(info.events.arch_event.archive_abs_change),
         ],
         [
             "Arch. rel. change",
-            tangoctl.value_str(info.events.arch_event.archive_rel_change),
+            core.value_str(info.events.arch_event.archive_rel_change),
         ],
-        ["Arch. period", tangoctl.value_str(info.events.arch_event.archive_period)],
-        ["Abs. change", tangoctl.value_str(info.events.ch_event.abs_change)],
-        ["Rel. change", tangoctl.value_str(info.events.ch_event.rel_change)],
-        ["Period", tangoctl.value_str(info.events.per_event.period)],
+        ["Arch. period", core.value_str(info.events.arch_event.archive_period)],
+        ["Abs. change", core.value_str(info.events.ch_event.abs_change)],
+        ["Rel. change", core.value_str(info.events.ch_event.rel_change)],
+        ["Period", core.value_str(info.events.per_event.period)],
         ["Enums", ", ".join(info.enum_labels) if info.enum_labels else "---"],
     ]
 
 
 @click.group(invoke_without_command=True)
+@color
 @click.pass_context
-def cli(ctx):
+def cli(ctx, color):
     """Query or send control commands to the tango system.
 
     Examples:
@@ -406,6 +404,8 @@ def cli(ctx):
     $ tangoctl device attribute list sys/tg_test/1
 
     """
+    ctx.color = color
+    ctx.info_name = "tangoctl"
     _prepare_logging()
     if ctx.invoked_subcommand is None:
         from . import repl
@@ -449,7 +449,7 @@ def device_list(device, class_, server, host, nb_cols, exclude_dserver):
     """
 
     with error():
-        devices = tangoctl.iter_devices(
+        devices = core.iter_devices(
             device=device,
             klass=class_,
             server=server,
@@ -466,9 +466,8 @@ def device_list(device, class_, server, host, nb_cols, exclude_dserver):
 @class_filter
 @server_filter
 @host_filter
-@color
 @dserver
-def device_table(device, class_, server, host, color, exclude_dserver):
+def device_table(device, class_, server, host, exclude_dserver):
     """
     Show table of devices.
 
@@ -491,8 +490,8 @@ def device_table(device, class_, server, host, color, exclude_dserver):
     """
     with error():
         db = None  # TODO: determine DB
-        db_info = tangoctl.get_db_info(db=db)
-        devices = tangoctl.iter_devices(
+        db_info = core.get_db_info(db=db)
+        devices = core.iter_devices(
             db=db,
             device=device,
             klass=class_,
@@ -504,12 +503,12 @@ def device_table(device, class_, server, host, color, exclude_dserver):
         for dev in devices:
             srv = db_info.servers[dev.server]
             row = [
-                _device_str(dev, color),
-                _alias_str(dev, color),
-                _device_class_str(dev, color),
-                _server_str(srv, color),
-                _server_host_str(srv, color),
-                _device_exported_str(dev, color),
+                _device_str(dev),
+                _alias_str(dev),
+                _device_class_str(dev),
+                _server_str(srv),
+                _server_host_str(srv),
+                _device_exported_str(dev),
             ]
             table.append(row)
         headers = ["Name", "Alias", "Class", "Server", "Host", "Exported"]
@@ -521,10 +520,10 @@ def device_table(device, class_, server, host, color, exclude_dserver):
 @class_filter
 @server_filter
 @host_filter
-@color
 @verbose
 @dserver
-def device_tree(device, class_, server, host, color, verbose, exclude_dserver):
+@click.pass_context
+def device_tree(ctx, device, class_, server, host, verbose, exclude_dserver):
     """
     Show a tree of devices.
 
@@ -561,14 +560,14 @@ def device_tree(device, class_, server, host, color, verbose, exclude_dserver):
     """
     with error():
         db = None
-        db_info = tangoctl.get_db_info(db=db)
+        db_info = core.get_db_info(db=db)
 
         import treelib
 
         tree = treelib.Tree()
         db_node = tree.create_node(db_info.name)
         all_servers = db_info.servers
-        devices = tangoctl.iter_devices(
+        devices = core.iter_devices(
             device=device,
             klass=class_,
             server=server,
@@ -582,27 +581,24 @@ def device_tree(device, class_, server, host, color, verbose, exclude_dserver):
         for dev in devices:
             d, f, m = dev.name.split("/")
             domains[d.lower()][f.lower()][m.lower()] = dev
-        if color:
-            VERBOSE_TEMPLATE = "{:30} {:30} {:35} {:40} {:40} {}"
-        else:
-            VERBOSE_TEMPLATE = "{:30} {:15} {:20} {:25} {:25} {}"
+        VERBOSE_TEMPLATE = "{:30} {:30} {:35} {:40} {:40} {}"
         for domain in sorted(domains):
-            d_node = tree.create_node(_device_str(domain, color), parent=db_node)
+            d_node = tree.create_node(_device_str(domain), parent=db_node)
             families = domains[domain]
             for family in sorted(families):
-                f_node = tree.create_node(_device_str(family, color), parent=d_node)
+                f_node = tree.create_node(_device_str(family), parent=d_node)
                 members = families[family]
                 for member in sorted(members):
                     if verbose:
                         dev = members[member]
                         srv = all_servers[dev.server]
                         text = VERBOSE_TEMPLATE.format(
-                            _device_str(member, color),
-                            _alias_str(dev, color),
-                            _device_class_str(dev, color),
-                            _server_str(srv, color),
-                            _server_host_str(srv, color),
-                            _device_exported_str(dev, color),
+                            _device_str(member),
+                            _alias_str(dev),
+                            _device_class_str(dev),
+                            _server_str(srv),
+                            _server_host_str(srv),
+                            _device_exported_str(dev),
                         )
                     else:
                         text = member
@@ -612,9 +608,8 @@ def device_tree(device, class_, server, host, color, verbose, exclude_dserver):
 
 @device_group.command("ping", help="ping device(s) (supports pattern matching *,?,[])")
 @devices
-@color
 @dserver
-def device_ping(devices, color, exclude_dserver):
+def device_ping(devices, exclude_dserver):
     """
     Ping device(s).
 
@@ -638,7 +633,7 @@ def device_ping(devices, color, exclude_dserver):
     """
     with error():
         devices = tuple(
-            tangoctl.expr_to_idevices(devices, exclude_dserver=exclude_dserver)
+            core.expr_to_idevices(devices, exclude_dserver=exclude_dserver)
         )
         if not devices:
             click.echo("no device matches the given pattern")
@@ -646,9 +641,9 @@ def device_ping(devices, color, exclude_dserver):
         device_names = [device.name for device in devices]
         size = max(map(len, device_names))
         template = "{{:{}}} ".format(size)
-        for dev_name, value in tangoctl.device_ping(device_names):
+        for dev_name, value in core.device_ping(device_names):
             if isinstance(value, Exception):
-                msg = tangoctl.tango_error_str(value)
+                msg = core.tango_error_str(value)
                 if "not exported" in msg:
                     msg = "not exported"
                 elif "Failed to connect" in msg:
@@ -656,7 +651,7 @@ def device_ping(devices, color, exclude_dserver):
             else:
                 msg = "{} us".format(value)
             click.echo(template.format(dev_name), nl=False)
-            click.secho(msg, color=color, fg=_time_color(value))
+            click.secho(msg, fg=_time_color(value))
 
 
 @device_group.command("add")
@@ -677,7 +672,7 @@ def device_add(server, device):
     Registered the/demo/device2 in TangoTest/demo
     """
     with error():
-        for serv, dev in tangoctl.device_add(server, device):
+        for serv, dev in core.device_add(server, device):
             click.echo("Registered {} in {}".format(dev, serv))
 
 
@@ -691,7 +686,7 @@ def device_delete(devices):
     $ tangoctl device delete -d the/demo/device1 -d the/demo/device2
     """
     with error():
-        tangoctl.device_delete(devices)
+        core.device_delete(devices)
 
 
 @device_group.group("alias")
@@ -703,7 +698,7 @@ def device_alias():
 @device
 def device_alias_show(device):
     """show the alias for the given device"""
-    click.echo(tangoctl.alias_from_device(device))
+    click.echo(core.alias_from_device(device))
 
 
 @device_alias.command("add")
@@ -711,14 +706,14 @@ def device_alias_show(device):
 @click.argument("alias", type=str)
 def device_alias_add(device, alias):
     """set the alias for the given device"""
-    tangoctl.set_device_alias(device, alias)
+    core.set_device_alias(device, alias)
 
 
 @device_alias.command("remove")
 @click.argument("alias", type=str)
 def device_alias_remove(device, alias):
     """unregister the alias from the database"""
-    tangoctl.remove_device_alias(alias)
+    core.remove_device_alias(alias)
 
 
 @device_group.group("command")
@@ -736,7 +731,7 @@ def device_command():
 def device_command_exec(device, command, parameter):
     """Execute a specific command"""
     with error():
-        click.echo(str(tangoctl.device_command(device, command, parameter)))
+        click.echo(str(core.device_command(device, command, parameter)))
 
 
 @device_command.command("list")
@@ -745,7 +740,7 @@ def device_command_exec(device, command, parameter):
 def device_command_list(device, nb_cols):
     """Show list of commands."""
     with error():
-        cmds = tangoctl.device_commands(device)
+        cmds = core.device_commands(device)
         cmd_names = [cmd.cmd_name for cmd in cmds]
         cmd_rows = _ls_columns(cmd_names, nb_cols=nb_cols)
         click.echo(_table(cmd_rows))
@@ -757,9 +752,9 @@ def device_command_table(device):
     """Show table of device commands."""
     rows = []
     with error():
-        for cmd in tangoctl.device_commands(device):
-            arg = tangoctl.type_str(cmd.in_type)
-            res = tangoctl.type_str(cmd.out_type)
+        for cmd in core.device_commands(device):
+            arg = core.type_str(cmd.in_type)
+            res = core.type_str(cmd.out_type)
             rows.append((cmd.cmd_name, arg, res))
         click.echo(_table(rows, headers=["Name", "Argument", "Return"]))
 
@@ -770,7 +765,7 @@ def device_command_table(device):
 def device_command_info(device, command):
     """Information about a command."""
     with error():
-        click.echo(str(tangoctl.device_command_info(device, command)))
+        click.echo(str(core.device_command_info(device, command)))
 
 
 @device_group.group("attribute")
@@ -782,20 +777,18 @@ def device_attribute():
 @device_attribute.command("read")
 @device
 @attrs_filter
-@color
-def device_attribute_read(device, attribute, color):
+def device_attribute_read(device, attribute):
     """Read a attribute(s) from device."""
     with error():
         rows = []
-        for dev_name, values in tangoctl.attributes_read({device: attribute}):
+        for dev_name, values in core.attributes_read({device: attribute}):
             if isinstance(values, Exception):
-                msg = tangoctl.tango_error_str(values)
-                click.secho(msg, fg="red", color=color)
+                msg = core.tango_error_str(values)
+                click.secho(msg, fg="red")
             else:
                 for value in values:
-                    value_str, fg = tangoctl.attr_value_str_color(value)
-                    if color:
-                        value_str = click.style(value_str, fg=fg)
+                    value_str, fg = core.attr_value_str_color(value)
+                    value_str = click.style(value_str, fg=fg)
                     rows.append((value["name"], value_str))
         click.echo(_table(rows))
 
@@ -807,7 +800,7 @@ def device_attribute_read(device, attribute, color):
 def device_attribute_write(device, attribute, value):
     """Write an attribute."""
     with error():
-        click.echo(tangoctl.device_attribute_write(device, attribute, value))
+        click.echo(core.device_attribute_write(device, attribute, value))
 
 
 @device_attribute.command("info")
@@ -826,7 +819,7 @@ def device_attribute_info(device, attribute):
 def device_attribute_list(device, nb_cols):
     """Show list of device attributes."""
     with error():
-        attrs = tangoctl.device_attributes(device)
+        attrs = core.device_attributes(device)
         attr_names = [attr.name for attr in attrs]
         attr_rows = _ls_columns(attr_names, nb_cols=nb_cols)
         click.echo(_table(attr_rows))
@@ -838,9 +831,9 @@ def device_attribute_table(device):
     """Show table of device attributes."""
     with error():
         rows = []
-        for attr in tangoctl.device_attributes(device):
-            atype = tangoctl.type_str(attr.data_type, attr.data_format)
-            rows.append((attr.name, atype, tangoctl.access_str(attr.writable)))
+        for attr in core.device_attributes(device):
+            atype = core.type_str(attr.data_type, attr.data_format)
+            rows.append((attr.name, atype, core.access_str(attr.writable)))
         click.echo(_table(rows))
 
 
@@ -857,7 +850,7 @@ def device_property_read(device, property):
     """Read device property(ies)."""
     rows = []
     with error():
-        props = tangoctl.device_properties_read(device, property)
+        props = core.device_properties_read(device, property)
         for name in sorted(props):
             value = props[name]
             if len(value) == 1:
@@ -873,7 +866,7 @@ def device_property_read(device, property):
 def device_property_write(device, property, value):
     """Write device property."""
     with error():
-        click.echo(tangoctl.device_property_write(device, property, value))
+        click.echo(core.device_property_write(device, property, value))
 
 
 @device_property.command("list")
@@ -882,7 +875,7 @@ def device_property_write(device, property, value):
 def device_property_list(device, nb_cols):
     """Show list of device properties and the corresponding value."""
     with error():
-        prop_names = tangoctl.device_property_list(device)
+        prop_names = core.device_property_list(device)
         rows = _ls_columns(prop_names, nb_cols=nb_cols)
         click.echo(_table(rows))
 
@@ -910,7 +903,7 @@ def device_info(device):
          version = 4
     """
     with error():
-        dinfo = tangoctl.device_info(device)
+        dinfo = core.device_info(device)
         templ = "{{:>{}}} = {{}}".format(max(map(len, dinfo)))
         lines = [templ.format(name, dinfo[name]) for name in sorted(dinfo)]
         click.echo("\n".join(lines))
@@ -941,7 +934,7 @@ def server_list(server, nb_cols):
     LimaCCDs/Simulator_test  LimaCCDs/tcoutinho
     """
     with error():
-        servers = list(tangoctl.iter_servers(server=server))
+        servers = list(core.iter_servers(server=server))
         server_names = [s.name for s in servers]
         server_rows = _ls_columns(server_names, nb_cols=nb_cols)
         click.echo(_table(server_rows))
@@ -966,7 +959,7 @@ def server_instance_list(server_type, server_instance, nb_cols):
     """
     with error():
         servers = list(
-            tangoctl.iter_servers(
+            core.iter_servers(
                 server_type=server_type, server_instance=server_instance
             )
         )
@@ -979,7 +972,7 @@ def server_instance_list(server_type, server_instance, nb_cols):
 @servers
 def server_stop(servers):
     with error():
-        server_names = tuple(tangoctl.expr_to_iservers(servers))
+        server_names = tuple(core.expr_to_iservers(servers))
         if not server_names:
             click.echo("no server matches the given pattern")
             return
@@ -988,8 +981,7 @@ def server_stop(servers):
 
 @server_group.command("ping")
 @servers
-@color
-def server_ping(servers, color):
+def server_ping(servers):
     """
     Ping server(s).
 
@@ -1003,15 +995,15 @@ def server_ping(servers, color):
     LimaCCDs/imxpad2        failed to connect
     """
     with error():
-        server_names = tuple(tangoctl.expr_to_iservers(servers))
+        server_names = tuple(core.expr_to_iservers(servers))
         if not server_names:
             click.echo("no server matches the given pattern")
             return
         size = max(map(len, server_names))
         template = "{{:{}}} ".format(size)
-        for server_name, value in tangoctl.server_ping(server_names):
+        for server_name, value in core.server_ping(server_names):
             if isinstance(value, Exception):
-                msg = tangoctl.tango_error_str(value)
+                msg = core.tango_error_str(value)
                 if "not exported" in msg:
                     msg = "not exported"
                 elif "Failed to connect" in msg:
@@ -1019,7 +1011,7 @@ def server_ping(servers, color):
             else:
                 msg = "{} us".format(value)
             click.echo(template.format(server_name), nl=False)
-            click.secho(msg, color=color, fg=_time_color(value))
+            click.secho(msg, fg=_time_color(value))
 
 
 @server_group.command("add")
@@ -1040,14 +1032,13 @@ def server_add(server, device):
     Registered the/demo/device2 in TangoTest/demo
     """
     with error():
-        for serv, dev in tangoctl.server_add(server, device):
+        for serv, dev in core.server_add(server, device):
             click.echo("Registered {} in {}".format(dev, serv))
 
 
 @server_group.command("delete")
 @servers
-@color
-def server_delete(servers, color):
+def server_delete(servers):
     """
     Unregister existing server(s).
 
@@ -1065,11 +1056,11 @@ def server_delete(servers, color):
         for server in servers:
             click.echo("Deleting {}... ".format(server), nl=False)
             try:
-                tangoctl.server_delete(server)
-                click.secho("[DONE]", fg="green", color=color)
+                core.server_delete(server)
+                click.secho("[DONE]", fg="green")
             except Exception as err:
-                msg = " ({})".format(tangoctl.tango_error_str(err, stack_message=0))
-                click.secho("[ERROR]", fg="red", color=color, nl=False)
+                msg = " ({})".format(core.tango_error_str(err, stack_message=0))
+                click.secho("[ERROR]", fg="red", nl=False)
                 click.echo(msg)
 
 
@@ -1094,7 +1085,7 @@ def server_info(server):
          version = 4
     """
     with error():
-        sinfo = tangoctl.server_info(server)
+        sinfo = core.server_info(server)
         templ = "{{:>{}}} = {{}}".format(max(map(len, sinfo)))
         lines = [templ.format(name, sinfo[name]) for name in sorted(sinfo)]
         click.echo("\n".join(lines))
@@ -1142,7 +1133,7 @@ def server_tree(
             ├── sys/tg_test/tc2
             └── sys/tg_test/tc3
     """
-    tree = tangoctl.server_tree(
+    tree = core.server_tree(
         server_name=server,
         server_type=server_type,
         server_instance=server_instance,
@@ -1164,20 +1155,18 @@ def attribute_group():
 @attribute_group.command("read")
 @device
 @attrs_filter
-@color
-def attribute_read(device, attribute, color):
+def attribute_read(device, attribute):
     """Read an attribute."""
     with error():
         rows = []
-        for dev_name, values in tangoctl.attributes_read({device: attribute}):
+        for dev_name, values in core.attributes_read({device: attribute}):
             if isinstance(values, Exception):
-                msg = tangoctl.tango_error_str(values)
-                click.secho(msg, fg="red", color=color)
+                msg = core.tango_error_str(values)
+                click.secho(msg, fg="red")
             else:
                 for value in values:
-                    value_str, fg = tangoctl.attr_value_str_color(value)
-                    if color:
-                        value_str = click.style(value_str, fg=fg)
+                    value_str, fg = core.attr_value_str_color(value)
+                    value_str = click.style(value_str, fg=fg)
                     rows.append((value["name"], value_str))
         click.echo(_table(rows))
 
@@ -1189,7 +1178,7 @@ def attribute_read(device, attribute, color):
 def attribute_write(device, attribute, value):
     """Write an attribute."""
     with error():
-        click.echo(tangoctl.device_attribute_write(device, attribute, value))
+        click.echo(core.device_attribute_write(device, attribute, value))
 
 
 @attribute_group.command("info")
@@ -1217,7 +1206,7 @@ def command_group():
 def command_exec(device, command, parameter):
     """Execute a specific command."""
     with error():
-        click.echo(str(tangoctl.device_command(device, command, parameter)))
+        click.echo(str(core.device_command(device, command, parameter)))
 
 
 @cli.group("starter")
@@ -1260,13 +1249,12 @@ def starter_tree(starter, server, server_type, server_instance, all):
             ├── Sardana/BL04
             └── Lima/basler-01
     """
-    tree = tangoctl.starter_tree(
+    tree = core.starter_tree(
         starter_name=starter,
         server_name=server,
         server_type=server_type,
         server_instance=server_instance,
         all=all,
-        colored=True,
     )
     click.echo(str(tree))
 
@@ -1277,7 +1265,7 @@ def _starter_stop(
     if dry_run:
         click.secho("Making a dry run!", bold=True, fg="red")
     try:
-        tangoctl.starter_stop_servers(
+        core.starter_stop_servers(
             starter_name=starter,
             server_name=server,
             server_type=server_type,
@@ -1294,7 +1282,7 @@ def _starter_start(starter, server, server_type, server_instance, timeout, dry_r
     if dry_run:
         click.secho("Making a dry run!", bold=True, fg="red")
     try:
-        tangoctl.starter_start_servers(
+        core.starter_start_servers(
             starter_name=starter,
             server_name=server,
             server_type=server_type,
@@ -1311,7 +1299,7 @@ def _starter_restart(starter, server, server_type, server_instance, timeout, dry
     if dry_run:
         click.secho("Making a dry run!", bold=True, fg="red")
     try:
-        tangoctl.starter_restart_servers(
+        core.starter_restart_servers(
             starter_name=starter,
             server_name=server,
             server_type=server_type,
