@@ -1,3 +1,10 @@
+# -*- coding: utf-8 -*-
+#
+# This file is part of the tangoctl project
+#
+# Copyright (c) 2018-2020 Tiago Coutinho
+# Distributed under the GPLv3 license. See LICENSE for more info.
+
 import shlex
 import getpass
 import functools
@@ -13,7 +20,7 @@ from prompt_toolkit.key_binding import KeyBindings
 from prompt_toolkit.auto_suggest import AutoSuggestFromHistory
 
 
-from tangoctl import tangoctl
+from tangoctl import core
 
 output = click.echo
 
@@ -24,11 +31,11 @@ class Toolbar:
 
     @property
     def db_info(self):
-        return tangoctl.get_db_info(self.db)
+        return core.get_db_info(self.db)
 
     @property
     def db_name(self):
-        return tangoctl.get_db_name(self.db)
+        return core.get_db_name(self.db)
 
     def __call__(self):
         db_info = self.db_info
@@ -100,7 +107,7 @@ class ClickCompleter(Completer):
 
 def Prompt(context):
     # TODO receive db name from context
-    db = tangoctl._get_db()
+    db = core._get_db()
     return PromptSession(
         completer=ClickCompleter(context.command),
         history=InMemoryHistory(),
